# NeonAI Nemo Remote STT Plugin 
[Mycroft](https://mycroft-ai.gitbook.io/docs/mycroft-technologies/mycroft-core/plugins) compatible
Neon Nemo Remote Speech-to-Text Plugin.

## Configuration:
```yaml
stt:
    module: neon-stt-plugin-nemo-remote
    neon-stt-plugin-nemo:
      url: "https://nemo.neonaialpha.com"
```
